.. Sage Constructions documentation master file, created by sphinx-quickstart on Fri Aug 22 12:10:42 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _constructions:

=============================
Welcome to Sage Constructions
=============================

This document collects the answers to some questions along the line
"How do I construct ... in Sage?" Though much of this material can
be found in the manual or tutorial or string documentation of the
Python code, it is hoped that this will provide the casual user
with some basic examples on how to start using Sage in a useful
way.

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ http://creativecommons.org/licenses/by-sa/3.0/

Please send suggestions, additions, corrections to the ``sage-devel``
Google group!

The Sage wiki http://wiki.sagemath.org/ contains a wealth of
information. Moreover, all these can be tested in the Sage
interface http://sagecell.sagemath.org/ on the web.


.. toctree::
   :maxdepth: 2

   calculus
   plotting
   groups
   linear_algebra
   linear_codes
   rep_theory
   rings
   polynomials
   number_theory
   modular_forms
   elliptic_curves
   number_fields
   algebraic_geometry
   interface_issues
   contributions


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

